@@ -23,6 +23,7 @@
 #include "imapparser_p.h"
 #include "job.h"
 #include "job_p.h"
+#include "servermanager.h"
 #include "servermanager_p.h"
 #include "xdgbasedirs_p.h"
 
@@ -34,10 +35,18 @@
 #include <QtCore/QQueue>
 #include <QtCore/QThreadStorage>
 #include <QtCore/QTimer>
+#include <QtCore/QThread>
+#include <QSettings>
 
 #include <QtNetwork/QLocalSocket>
+#include <QtNetwork/QTcpSocket>
+#include <QtNetwork/QHostAddress>
 
-#define PIPELINE_LENGTH 2
+// ### FIXME pipelining got broken by switching result emission in JobPrivate::handleResponse to delayed emission
+// in order to work around exec() deadlocks. As a result of that Session knows to late about a finished job and still
+// sends responses for the next one to the already finished one
+#define PIPELINE_LENGTH 0
+//#define PIPELINE_LENGTH 2
 
 using namespace Akonadi;
 
@@ -51,24 +60,118 @@ void SessionPrivate::startNext()
 
 void SessionPrivate::reconnect()
 {
-  // should be checking connection method and value validity
-  if ( socket->state() != QLocalSocket::ConnectedState &&
-       socket->state() != QLocalSocket::ConnectingState ) {
+  QLocalSocket *localSocket = qobject_cast<QLocalSocket*>( socket );
+  if ( localSocket && (localSocket->state() == QLocalSocket::ConnectedState
+                       || localSocket->state() == QLocalSocket::ConnectingState ) ) {
+    // nothing to do, we are still/already connected
+    return;
+  }
+
+  QTcpSocket *tcpSocket = qobject_cast<QTcpSocket*>( socket );
+  if ( tcpSocket && (tcpSocket->state() == QTcpSocket::ConnectedState
+                     || tcpSocket->state() == QTcpSocket::ConnectingState ) ) {
+    // same here, but for TCP
+    return;
+  }
+
+  // try to figure out where to connect to
+  QString serverAddress;
+  quint16 port = 0;
+  bool useTcp = false;
+
+  // env var has precedence
+  const QByteArray serverAddressEnvVar = qgetenv( "AKONADI_SERVER_ADDRESS" );
+  if ( !serverAddressEnvVar.isEmpty() ) {
+    const int pos = serverAddressEnvVar.indexOf( ':' );
+    const QByteArray protocol = serverAddressEnvVar.left( pos  );
+    QMap<QString, QString> options;
+    foreach ( const QString &entry, QString::fromLatin1( serverAddressEnvVar.mid( pos + 1 ) ).split( QLatin1Char(',') ) ) {
+      const QStringList pair = entry.split( QLatin1Char('=') );
+      if ( pair.size() != 2 )
+        continue;
+      options.insert( pair.first(), pair.last() );
+    }
+    kDebug() << protocol << options;
+
+    if ( protocol == "tcp" ) {
+      serverAddress = options.value( QLatin1String( "host" ) );
+      port = options.value( QLatin1String( "port" ) ).toUInt();
+      useTcp = true;
+    } else if ( protocol == "unix" ) {
+      serverAddress = options.value( QLatin1String( "path" ) );
+    } else if ( protocol == "pipe" ) {
+      serverAddress = options.value( QLatin1String( "name" ) );
+    }
+  }
+
+  // try config file next, fall back to defaults if that fails as well
+  if ( serverAddress.isEmpty() ) {
+    const QString connectionConfigFile = connectionFile();
+    const QFileInfo fileInfo( connectionConfigFile );
+    if ( !fileInfo.exists() ) {
+      kDebug() << "Akonadi Client Session: connection config file '"
+                  "akonadi/akonadiconnectionrc' can not be found in"
+               << XdgBaseDirs::homePath( "config" ) << "nor in any of"
+               << XdgBaseDirs::systemPathList( "config" );
+    }
+    const QSettings connectionSettings( connectionConfigFile, QSettings::IniFormat );
+
 #ifdef Q_OS_WIN  //krazy:exclude=cpp
-    const QString namedPipe = mConnectionSettings->value( QLatin1String( "Data/NamedPipe" ), QLatin1String( "Akonadi" ) ).toString();
-    socket->connectToServer( namedPipe );
+    serverAddress = connectionSettings.value( QLatin1String( "Data/NamedPipe" ), QLatin1String( "Akonadi" ) ).toString();
 #else
-    const QString defaultSocketDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi" ) );
-    const QString path = mConnectionSettings->value( QLatin1String( "Data/UnixPath" ), defaultSocketDir + QLatin1String( "/akonadiserver.socket" ) ).toString();
-    socket->connectToServer( path );
+    const QString defaultSocketDir = Internal::xdgSaveDir( "data" );
+    serverAddress = connectionSettings.value( QLatin1String( "Data/UnixPath" ), QString(defaultSocketDir + QLatin1String( "/akonadiserver.socket" )) ).toString();
 #endif
   }
+#ifdef Q_OS_WINCE
+  useTcp = true;
+#endif
+
+  // create sockets if not yet done, note that this does not yet allow changing socket types on the fly
+  // but that's probably not something we need to support anyway
+  if ( !socket ) {
+    if ( !useTcp ) {
+      socket = localSocket = new QLocalSocket( mParent );
+      mParent->connect( localSocket, SIGNAL(error(QLocalSocket::LocalSocketError)), SLOT(socketError(QLocalSocket::LocalSocketError)) );
+    } else {
+      socket = tcpSocket = new QTcpSocket( mParent );
+      mParent->connect( tcpSocket, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(socketError(QAbstractSocket::SocketError)) );
+    }
+    mParent->connect( socket, SIGNAL(disconnected()), SLOT(socketDisconnected()) );
+    mParent->connect( socket, SIGNAL(readyRead()), SLOT(dataReceived()) );
+  }
+
+  // actually do connect
+  kDebug() << "connectToServer" << serverAddress;
+#ifdef Q_OS_WINCE
+    tcpSocket->connectToHost( QHostAddress::LocalHost, 31414 );
+#else
+  if ( !useTcp ) {
+    localSocket->connectToServer( serverAddress );
+  } else {
+    tcpSocket->connectToHost( serverAddress, port );
+  }
+#endif
+
+  emit mParent->reconnected();
+}
+
+QString SessionPrivate::connectionFile()
+{
+  return Internal::xdgSaveDir( "config" ) + QLatin1String("/akonadiconnectionrc");
 }
 
 void SessionPrivate::socketError( QLocalSocket::LocalSocketError )
 {
   Q_ASSERT( mParent->sender() == socket );
-  kWarning() << "Socket error occurred:" << socket->errorString();
+  kWarning() << "Socket error occurred:" << qobject_cast<QLocalSocket*>( socket )->errorString();
+  socketDisconnected();
+}
+
+void SessionPrivate::socketError( QAbstractSocket::SocketError )
+{
+  Q_ASSERT( mParent->sender() == socket );
+  kWarning() << "Socket error occurred:" << qobject_cast<QTcpSocket*>( socket )->errorString();
   socketDisconnected();
 }
 
@@ -77,7 +180,6 @@ void SessionPrivate::socketDisconnected()
   if ( currentJob )
     currentJob->d_ptr->lostConnection();
   connected = false;
-  QTimer::singleShot( 1000, mParent, SLOT(reconnect()) );
 }
 
 void SessionPrivate::dataReceived()
@@ -91,7 +193,7 @@ void SessionPrivate::dataReceived()
         continue; // response not yet completed
 
       // handle login response
-      if ( parser->tag() == QByteArray("0") ) {
+      if ( parser->tag() == QByteArray( "0" ) ) {
         if ( parser->data().startsWith( "OK" ) ) { //krazy:exclude=strings
           connected = true;
           startNext();
@@ -178,7 +280,9 @@ void SessionPrivate::endJob( Job *job )
 
 void SessionPrivate::jobDone(KJob * job)
 {
-  if( job == currentJob ) {
+  // ### careful, this method can be called from the QObject dtor of job (see jobDestroyed() below)
+  // so don't call any methods on job itself
+  if ( job == currentJob ) {
     if ( pipeline.isEmpty() ) {
       jobRunning = false;
       currentJob = 0;
@@ -186,10 +290,11 @@ void SessionPrivate::jobDone(KJob * job)
       currentJob = pipeline.dequeue();
     }
     startNext();
-  }
-  // ### better handle the other cases too, user might have canceled jobs
-  else {
-    kDebug() << job << "Non-current job finished.";
+  } else {
+    // non-current job finished, likely canceled while still in the queue
+    queue.removeAll( static_cast<Akonadi::Job*>( job ) );
+    // ### likely not enough to really cancel already running jobs
+    pipeline.removeAll( static_cast<Akonadi::Job*>( job ) );
   }
 }
 
@@ -203,13 +308,8 @@ void SessionPrivate::jobWriteFinished( Akonadi::Job* job )
 
 void SessionPrivate::jobDestroyed(QObject * job)
 {
-  queue.removeAll( static_cast<Akonadi::Job*>( job ) );
-  // ### likely not enough to really cancel already running jobs
-  pipeline.removeAll( static_cast<Akonadi::Job*>( job ) );
-  if ( currentJob == job ) {
-    currentJob = 0;
-    jobRunning = false;
-  }
+  // careful, accessing non-QObject methods of job will fail here already
+  jobDone( static_cast<KJob*>( job ) );
 }
 
 void SessionPrivate::addJob(Job * job)
@@ -228,19 +328,37 @@ int SessionPrivate::nextTag()
 
 void SessionPrivate::writeData(const QByteArray & data)
 {
-  socket->write( data );
+  if ( socket )
+    socket->write( data );
+  else
+    kWarning() << "Trying to write while session is disconnected!" << kBacktrace();
+}
+
+void SessionPrivate::serverStateChanged( ServerManager::State state )
+{
+  if ( state == ServerManager::Running && !connected )
+    reconnect();
+}
+
+void SessionPrivate::itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevision, int newRevision )
+{
+  // only deal with the queue, for the guys in the pipeline it's too late already anyway
+  // and they shouldn't have gotten there if they depend on a preceding job anyway.
+  foreach ( Job *job, queue )
+    job->d_ptr->updateItemRevision( itemId, oldRevision, newRevision );
 }
 
 //@endcond
 
 
 SessionPrivate::SessionPrivate( Session *parent )
-    : mParent( parent ), mConnectionSettings( 0 ), protocolVersion( 0 ), currentJob( 0 ), parser( 0 )
+    : mParent( parent ), socket( 0 ), protocolVersion( 0 ), currentJob( 0 ), parser( 0 )
 {
 }
 
 void SessionPrivate::init( const QByteArray &id )
 {
+  kDebug() << id;
   parser = new ImapParser();
 
   if ( !id.isEmpty() ) {
@@ -254,27 +372,27 @@ void SessionPrivate::init( const QByteArray &id )
   theNextTag = 1;
   jobRunning = false;
 
-  const QString connectionConfigFile = XdgBaseDirs::akonadiConnectionConfigFile();
+  if ( ServerManager::state() == ServerManager::NotRunning )
+    ServerManager::start();
+  mParent->connect( ServerManager::self(), SIGNAL(stateChanged(Akonadi::ServerManager::State)),
+                    SLOT(serverStateChanged(Akonadi::ServerManager::State)) );
 
-  QFileInfo fileInfo( connectionConfigFile );
-  if ( !fileInfo.exists() ) {
-    kWarning() << "Akonadi Client Session: connection config file '"
-               << "akonadi/akonadiconnectionrc can not be found in '"
-               << XdgBaseDirs::homePath( "config" ) << "' nor in any of "
-               << XdgBaseDirs::systemPathList( "config" );
-  }
-
-  mConnectionSettings = new QSettings( connectionConfigFile, QSettings::IniFormat );
-
-  // should check connection method
-  socket = new QLocalSocket( mParent );
-
-  mParent->connect( socket, SIGNAL(disconnected()), SLOT(socketDisconnected()) );
-  mParent->connect( socket, SIGNAL(error(QLocalSocket::LocalSocketError)), SLOT(socketError(QLocalSocket::LocalSocketError)) );
-  mParent->connect( socket, SIGNAL(readyRead()), SLOT(dataReceived()) );
   reconnect();
 }
 
+void SessionPrivate::forceReconnect()
+{
+  jobRunning = false;
+  connected = false;
+  if ( socket ) {
+    socket->disconnect( mParent ); // prevent signal emitted from close() causing mayhem - we might be called from ~QThreadStorage!
+    delete socket;
+  }
+  socket = 0;
+  QMetaObject::invokeMethod( mParent, "reconnect", Qt::QueuedConnection ); // avoids reconnecting in the dtor
+}
+
+
 Session::Session(const QByteArray & sessionId, QObject * parent) :
     QObject( parent ),
     d( new SessionPrivate( this ) )
@@ -300,7 +418,7 @@ QByteArray Session::sessionId() const
   return d->sessionId;
 }
 
-QThreadStorage<Session*> instances;
+static QThreadStorage<Session*> instances;
 
 void SessionPrivate::createDefaultSession( const QByteArray &sessionId )
 {
@@ -322,10 +440,18 @@ Session* Session::defaultSession()
 void Session::clear()
 {
   foreach ( Job* job, d->queue )
-    job->kill( KJob::EmitResult );
+    job->kill( KJob::EmitResult ); // safe, not started yet
   d->queue.clear();
-  if ( d->currentJob )
+  foreach ( Job* job, d->pipeline ) {
+    job->d_ptr->mStarted = false; // avoid killing/reconnect loops
+    job->kill( KJob::EmitResult );
+  }
+  d->pipeline.clear();
+  if ( d->currentJob ) {
+    d->currentJob->d_ptr->mStarted = false; // avoid killing/reconnect loops
     d->currentJob->kill( KJob::EmitResult );
+  }
+  d->forceReconnect();
 }
 
-#include "session.moc"
+#include "moc_session.cpp"
