@@ -74,15 +74,16 @@ VCardTool::~VCardTool()
 
 QByteArray VCardTool::exportVCards( const Addressee::List &list, VCard::Version version ) const
 {
-    return createVCards(list,version, true /*export vcard*/);
+  return createVCards( list, version, true /*export vcard*/);
 }
 
 QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version version ) const
 {
-    return createVCards(list,version, false/*don't export*/);
+  return createVCards( list, version, false /*don't export*/);
 }
 
-QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version version, bool exportVcard ) const
+QByteArray VCardTool::createVCards( const Addressee::List &list,
+                                    VCard::Version version, bool exportVcard ) const
 {
   VCard::List vCardList;
 
@@ -93,25 +94,38 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     QStringList::ConstIterator strIt;
 
     // ADR + LABEL
-    const Address::List addresses = (*addrIt).addresses();
+    const Address::List addresses = ( *addrIt ).addresses();
     for ( Address::List::ConstIterator it = addresses.begin(); it != addresses.end(); ++it ) {
       QStringList address;
 
-      const bool isEmpty = ( (*it).postOfficeBox().isEmpty() &&
-                             (*it).extended().isEmpty() &&
-                             (*it).street().isEmpty() &&
-                             (*it).locality().isEmpty() &&
-                             (*it).region().isEmpty() &&
-                             (*it).postalCode().isEmpty() &&
-                             (*it).country().isEmpty() );
+      const bool isEmpty = ( ( *it ).postOfficeBox().isEmpty() &&
+                             ( *it ).extended().isEmpty() &&
+                             ( *it ).street().isEmpty() &&
+                             ( *it ).locality().isEmpty() &&
+                             ( *it ).region().isEmpty() &&
+                             ( *it ).postalCode().isEmpty() &&
+                             ( *it ).country().isEmpty() );
 
-      address.append( (*it).postOfficeBox().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-      address.append( (*it).extended().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-      address.append( (*it).street().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-      address.append( (*it).locality().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-      address.append( (*it).region().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-      address.append( (*it).postalCode().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-      address.append( (*it).country().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
+      address.append( ( *it ).postOfficeBox().replace( QLatin1Char( ';' ),
+                                                       QLatin1String( "\\;" ) ) );
+
+      address.append( ( *it ).extended().replace( QLatin1Char( ';' ),
+                                                  QLatin1String( "\\;" ) ) );
+
+      address.append( ( *it ).street().replace( QLatin1Char( ';' ),
+                                                QLatin1String( "\\;" ) ) );
+
+      address.append( ( *it ).locality().replace( QLatin1Char( ';' ),
+                                                  QLatin1String( "\\;" ) ) );
+
+      address.append( ( *it ).region().replace( QLatin1Char( ';' ),
+                                                QLatin1String( "\\;" ) ) );
+
+      address.append( ( *it ).postalCode().replace( QLatin1Char( ';' ),
+                                                    QLatin1String( "\\;" ) ) );
+
+      address.append( ( *it ).country().replace( QLatin1Char( ';' ),
+                                                 QLatin1String( "\\;" ) ) );
 
       VCardLine adrLine( QLatin1String( "ADR" ), address.join( QLatin1String( ";" ) ) );
       if ( version == VCard::v2_1 && needsEncoding( address.join( QLatin1String( ";" ) ) ) ) {
@@ -119,17 +133,17 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
         adrLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
       }
 
-      VCardLine labelLine( QLatin1String( "LABEL" ), (*it).label() );
-      if ( version == VCard::v2_1 && needsEncoding( (*it).label() ) ) {
+      VCardLine labelLine( QLatin1String( "LABEL" ), ( *it ).label() );
+      if ( version == VCard::v2_1 && needsEncoding( ( *it ).label() ) ) {
         labelLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
         labelLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
       }
 
-      const bool hasLabel = !(*it).label().isEmpty();
+      const bool hasLabel = !( *it ).label().isEmpty();
       QMap<QString, Address::TypeFlag>::ConstIterator typeIt;
       for ( typeIt = mAddressTypeMap.constBegin();
             typeIt != mAddressTypeMap.constEnd(); ++typeIt ) {
-        if ( typeIt.value() & (*it).type() ) {
+        if ( typeIt.value() & ( *it ).type() ) {
           adrLine.addParameter( QLatin1String( "TYPE" ), typeIt.key() );
           if ( hasLabel ) {
             labelLine.addParameter( QLatin1String( "TYPE" ), typeIt.key() );
@@ -146,14 +160,15 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     }
 
     // BDAY
-    card.addLine( VCardLine( QLatin1String( "BDAY" ), createDateTime( (*addrIt).birthday() ) ) );
+    card.addLine( VCardLine( QLatin1String( "BDAY" ), createDateTime( ( *addrIt ).birthday() ) ) );
 
     // CATEGORIES
     if ( version == VCard::v3_0 ) {
-      QStringList categories = (*addrIt).categories();
+      QStringList categories = ( *addrIt ).categories();
       QStringList::Iterator catIt;
-      for ( catIt = categories.begin(); catIt != categories.end(); ++catIt ) {
-        (*catIt).replace( QLatin1Char( ',' ), QLatin1String( "\\," ) );
+      QStringList::Iterator catEnd( categories.end() );
+      for ( catIt = categories.begin(); catIt != catEnd; ++catIt ) {
+        ( *catIt ).replace( QLatin1Char( ',' ), QLatin1String( "\\," ) );
       }
 
       VCardLine catLine( QLatin1String( "CATEGORIES" ), categories.join( QLatin1String( "," ) ) );
@@ -162,11 +177,11 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
 
     // CLASS
     if ( version == VCard::v3_0 ) {
-      card.addLine( createSecrecy( (*addrIt).secrecy() ) );
+      card.addLine( createSecrecy( ( *addrIt ).secrecy() ) );
     }
 
     // EMAIL
-    const QStringList emails = (*addrIt).emails();
+    const QStringList emails = ( *addrIt ).emails();
     bool pref = true;
     for ( strIt = emails.begin(); strIt != emails.end(); ++strIt ) {
       VCardLine line( QLatin1String( "EMAIL" ), *strIt );
@@ -178,15 +193,15 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     }
 
     // FN
-    VCardLine fnLine( QLatin1String( "FN" ), (*addrIt).formattedName() );
-    if ( version == VCard::v2_1 && needsEncoding( (*addrIt).formattedName() ) ) {
+    VCardLine fnLine( QLatin1String( "FN" ), ( *addrIt ).formattedName() );
+    if ( version == VCard::v2_1 && needsEncoding( ( *addrIt ).formattedName() ) ) {
       fnLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
       fnLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
     }
     card.addLine( fnLine );
 
     // GEO
-    const Geo geo = (*addrIt).geo();
+    const Geo geo = ( *addrIt ).geo();
     if ( geo.isValid() ) {
       QString str;
       str.sprintf( "%.6f;%.6f", geo.latitude(), geo.longitude() );
@@ -194,18 +209,19 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     }
 
     // KEY
-    const Key::List keys = (*addrIt).keys();
+    const Key::List keys = ( *addrIt ).keys();
     Key::List::ConstIterator keyIt;
-    for ( keyIt = keys.begin(); keyIt != keys.end(); ++keyIt ) {
+    Key::List::ConstIterator keyEnd( keys.end() );
+    for ( keyIt = keys.begin(); keyIt != keyEnd; ++keyIt ) {
       card.addLine( createKey( *keyIt ) );
     }
 
     // LOGO
-    card.addLine( createPicture( QLatin1String( "LOGO" ), (*addrIt).logo() ) );
+    card.addLine( createPicture( QLatin1String( "LOGO" ), ( *addrIt ).logo() ) );
 
     // MAILER
-    VCardLine mailerLine( QLatin1String( "MAILER" ), (*addrIt).mailer() );
-    if ( version == VCard::v2_1 && needsEncoding( (*addrIt).mailer() ) ) {
+    VCardLine mailerLine( QLatin1String( "MAILER" ), ( *addrIt ).mailer() );
+    if ( version == VCard::v2_1 && needsEncoding( ( *addrIt ).mailer() ) ) {
       mailerLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
       mailerLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
     }
@@ -213,11 +229,20 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
 
     // N
     QStringList name;
-    name.append( (*addrIt).familyName().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-    name.append( (*addrIt).givenName().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-    name.append( (*addrIt).additionalName().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-    name.append( (*addrIt).prefix().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
-    name.append( (*addrIt).suffix().replace( QLatin1Char( ';' ), QLatin1String( "\\;" ) ) );
+    name.append( ( *addrIt ).familyName().replace( QLatin1Char( ';' ),
+                                                   QLatin1String( "\\;" ) ) );
+
+    name.append( ( *addrIt ).givenName().replace( QLatin1Char( ';' ),
+                                                  QLatin1String( "\\;" ) ) );
+
+    name.append( ( *addrIt ).additionalName().replace( QLatin1Char( ';' ),
+                                                       QLatin1String( "\\;" ) ) );
+
+    name.append( ( *addrIt ).prefix().replace( QLatin1Char( ';' ),
+                                               QLatin1String( "\\;" ) ) );
+
+    name.append( ( *addrIt ).suffix().replace( QLatin1Char( ';' ),
+                                               QLatin1String( "\\;" ) ) );
 
     VCardLine nLine( QLatin1String( "N" ), name.join( QLatin1String( ";" ) ) );
     if ( version == VCard::v2_1 && needsEncoding( name.join( QLatin1String( ";" ) ) ) ) {
@@ -227,8 +252,8 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     card.addLine( nLine );
 
     // NAME
-    VCardLine nameLine( QLatin1String( "NAME" ), (*addrIt).name() );
-    if ( version == VCard::v2_1 && needsEncoding( (*addrIt).name() ) ) {
+    VCardLine nameLine( QLatin1String( "NAME" ), ( *addrIt ).name() );
+    if ( version == VCard::v2_1 && needsEncoding( ( *addrIt ).name() ) ) {
       nameLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
       nameLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
     }
@@ -236,12 +261,12 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
 
     // NICKNAME
     if ( version == VCard::v3_0 ) {
-      card.addLine( VCardLine( QLatin1String( "NICKNAME" ), (*addrIt).nickName() ) );
+      card.addLine( VCardLine( QLatin1String( "NICKNAME" ), ( *addrIt ).nickName() ) );
     }
 
     // NOTE
-    VCardLine noteLine( QLatin1String( "NOTE" ), (*addrIt).note() );
-    if ( version == VCard::v2_1 && needsEncoding( (*addrIt).note() ) ) {
+    VCardLine noteLine( QLatin1String( "NOTE" ), ( *addrIt ).note() );
+    if ( version == VCard::v2_1 && needsEncoding( ( *addrIt ).note() ) ) {
       noteLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
       noteLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
     }
@@ -263,19 +288,19 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     card.addLine( orgLine );
 
     // PHOTO
-    card.addLine( createPicture( QLatin1String( "PHOTO" ), (*addrIt).photo() ) );
+    card.addLine( createPicture( QLatin1String( "PHOTO" ), ( *addrIt ).photo() ) );
 
     // PROID
     if ( version == VCard::v3_0 ) {
-      card.addLine( VCardLine( QLatin1String( "PRODID" ), (*addrIt).productId() ) );
+      card.addLine( VCardLine( QLatin1String( "PRODID" ), ( *addrIt ).productId() ) );
     }
 
     // REV
-    card.addLine( VCardLine( QLatin1String( "REV" ), createDateTime( (*addrIt).revision() ) ) );
+    card.addLine( VCardLine( QLatin1String( "REV" ), createDateTime( ( *addrIt ).revision() ) ) );
 
     // ROLE
-    VCardLine roleLine( QLatin1String( "ROLE" ), (*addrIt).role() );
-    if ( version == VCard::v2_1 && needsEncoding( (*addrIt).role() ) ) {
+    VCardLine roleLine( QLatin1String( "ROLE" ), ( *addrIt ).role() );
+    if ( version == VCard::v2_1 && needsEncoding( ( *addrIt ).role() ) ) {
       roleLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
       roleLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
     }
@@ -283,21 +308,23 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
 
     // SORT-STRING
     if ( version == VCard::v3_0 ) {
-      card.addLine( VCardLine( QLatin1String( "SORT-STRING" ), (*addrIt).sortString() ) );
+      card.addLine( VCardLine( QLatin1String( "SORT-STRING" ), ( *addrIt ).sortString() ) );
     }
 
     // SOUND
-    card.addLine( createSound( (*addrIt).sound() ) );
+    card.addLine( createSound( ( *addrIt ).sound() ) );
 
     // TEL
-    const PhoneNumber::List phoneNumbers = (*addrIt).phoneNumbers();
+    const PhoneNumber::List phoneNumbers = ( *addrIt ).phoneNumbers();
     PhoneNumber::List::ConstIterator phoneIt;
-    for ( phoneIt = phoneNumbers.begin(); phoneIt != phoneNumbers.end(); ++phoneIt ) {
-      VCardLine line( QLatin1String( "TEL" ), (*phoneIt).number() );
+    PhoneNumber::List::ConstIterator phoneEnd( phoneNumbers.end() );
+    for ( phoneIt = phoneNumbers.begin(); phoneIt != phoneEnd; ++phoneIt ) {
+      VCardLine line( QLatin1String( "TEL" ), ( *phoneIt ).number() );
 
       QMap<QString, PhoneNumber::TypeFlag>::ConstIterator typeIt;
-      for ( typeIt = mPhoneTypeMap.constBegin(); typeIt != mPhoneTypeMap.constEnd(); ++typeIt ) {
-        if ( typeIt.value() & (*phoneIt).type() ) {
+      QMap<QString, PhoneNumber::TypeFlag>::ConstIterator typeEnd( mPhoneTypeMap.constEnd() );
+      for ( typeIt = mPhoneTypeMap.constBegin(); typeIt != typeEnd; ++typeIt ) {
+        if ( typeIt.value() & ( *phoneIt ).type() ) {
           line.addParameter( QLatin1String( "TYPE" ), typeIt.key() );
         }
       }
@@ -306,15 +333,15 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     }
 
     // TITLE
-    VCardLine titleLine( QLatin1String( "TITLE" ), (*addrIt).title() );
-    if ( version == VCard::v2_1 && needsEncoding( (*addrIt).title() ) ) {
+    VCardLine titleLine( QLatin1String( "TITLE" ), ( *addrIt ).title() );
+    if ( version == VCard::v2_1 && needsEncoding( ( *addrIt ).title() ) ) {
       titleLine.addParameter( QLatin1String( "charset" ), QLatin1String( "UTF-8" ) );
       titleLine.addParameter( QLatin1String( "encoding" ), QLatin1String( "QUOTED-PRINTABLE" ) );
     }
     card.addLine( titleLine );
 
     // TZ
-    const TimeZone timeZone = (*addrIt).timeZone();
+    const TimeZone timeZone = ( *addrIt ).timeZone();
     if ( timeZone.isValid() ) {
       QString str;
 
@@ -331,53 +358,55 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     }
 
     // UID
-    card.addLine( VCardLine( QLatin1String( "UID" ), (*addrIt).uid() ) );
+    card.addLine( VCardLine( QLatin1String( "UID" ), ( *addrIt ).uid() ) );
 
     // URL
-    card.addLine( VCardLine( QLatin1String( "URL" ), (*addrIt).url().url() ) );
+    card.addLine( VCardLine( QLatin1String( "URL" ), ( *addrIt ).url().url() ) );
 
     // VERSION
     if ( version == VCard::v2_1 ) {
       card.addLine( VCardLine( QLatin1String( "VERSION" ), QLatin1String( "2.1" ) ) );
-    }
-    if ( version == VCard::v3_0 ) {
+    } else if ( version == VCard::v3_0 ) {
       card.addLine( VCardLine( QLatin1String( "VERSION" ), QLatin1String( "3.0" ) ) );
     }
 
     // X-
-    const QStringList customs = (*addrIt).customs();
+    const QStringList customs = ( *addrIt ).customs();
     for ( strIt = customs.begin(); strIt != customs.end(); ++strIt ) {
       QString identifier = QLatin1String( "X-" ) +
-                                 (*strIt).left( (*strIt).indexOf( QLatin1Char( ':' ) ) );
-      const QString value = (*strIt).mid( (*strIt).indexOf( QLatin1Char( ':' ) ) + 1 );
+                                 ( *strIt ).left( ( *strIt ).indexOf( QLatin1Char( ':' ) ) );
+      const QString value = ( *strIt ).mid( ( *strIt ).indexOf( QLatin1Char( ':' ) ) + 1 );
       if ( value.isEmpty() ) {
         continue;
       }
       //Convert to standard identifier
-      if(exportVcard) {
-          if(identifier == QLatin1String("X-messaging/aim-All")) {
-              identifier = QLatin1String("X-AIM");
-          } else if(identifier == QLatin1String("X-messaging/icq-All")) {
-              identifier = QLatin1String("X-ICQ");
-          } else if(identifier == QLatin1String("X-messaging/xmpp-All")) {
-              identifier = QLatin1String("X-JABBER");
-          } else if(identifier == QLatin1String("X-messaging/msn-All")) {
-              identifier = QLatin1String("X-MSN");
-          } else if(identifier == QLatin1String("X-messaging/yahoo-All")) {
-              identifier = QLatin1String("X-YAHOO");
-          } else if(identifier == QLatin1String("X-messaging/gadu-All")) {
-              identifier = QLatin1String("X-GADUGADU");
-          } else if(identifier == QLatin1String("X-messaging/skype-All")) {
-              identifier = QLatin1String("X-SKYPE");
-          } else if(identifier == QLatin1String("X-messaging/groupwise-All")) {
-              identifier = QLatin1String("X-GROUPWISE");
-          } else if(identifier == QLatin1String("X-messaging/sms-All")) {
-              identifier = QLatin1String("X-SMS");
-          } else if(identifier == QLatin1String("X-messaging/meanwhile-All")) {
-              identifier = QLatin1String("X-MEANWHILE");
-          } else if ( identifier == QLatin1String( "X-messaging/irc-All" ) ) {
-            identifier = QLatin1String( "X-IRC" ); //Not defined by rfc but need for fixing #300869
-          }
+      if ( exportVcard ) {
+        if ( identifier == QLatin1String( "X-messaging/aim-All" ) ) {
+          identifier = QLatin1String( "X-AIM" );
+        } else if ( identifier == QLatin1String( "X-messaging/icq-All" ) ) {
+          identifier = QLatin1String( "X-ICQ" );
+        } else if ( identifier == QLatin1String( "X-messaging/xmpp-All" ) ) {
+          identifier = QLatin1String( "X-JABBER" );
+        } else if ( identifier == QLatin1String( "X-messaging/msn-All" ) ) {
+          identifier = QLatin1String( "X-MSN" );
+        } else if ( identifier == QLatin1String( "X-messaging/yahoo-All" ) ) {
+          identifier = QLatin1String( "X-YAHOO" );
+        } else if ( identifier == QLatin1String( "X-messaging/gadu-All" ) ) {
+          identifier = QLatin1String( "X-GADUGADU" );
+        } else if ( identifier == QLatin1String( "X-messaging/skype-All" ) ) {
+          identifier = QLatin1String( "X-SKYPE" );
+        } else if ( identifier == QLatin1String( "X-messaging/groupwise-All" ) ) {
+          identifier = QLatin1String( "X-GROUPWISE" );
+        } else if ( identifier == QLatin1String( "X-messaging/sms-All" ) ) {
+          identifier = QLatin1String( "X-SMS" );
+        } else if ( identifier == QLatin1String( "X-messaging/meanwhile-All" ) ) {
+          identifier = QLatin1String( "X-MEANWHILE" );
+        } else if ( identifier == QLatin1String( "X-messaging/irc-All" ) ) {
+          identifier = QLatin1String( "X-IRC" ); //Not defined by rfc but need for fixing #300869
+        } else if ( identifier == QLatin1String( "X-messaging/googletalk-All" ) ) {
+          //Not defined by rfc but need for fixing #300869
+          identifier = QLatin1String( "X-GOOGLETALK" );
+        }
       }
 
       VCardLine line( identifier, value );
@@ -408,20 +437,20 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
   for ( cardIt = vCardList.begin(); cardIt != listEnd; ++cardIt ) {
     Addressee addr;
 
-    const QStringList idents = (*cardIt).identifiers();
+    const QStringList idents = ( *cardIt ).identifiers();
     QStringList::ConstIterator identIt;
     QStringList::ConstIterator identEnd( idents.end() );
     for ( identIt = idents.begin(); identIt != identEnd; ++identIt ) {
-      const VCardLine::List lines = (*cardIt).lines( (*identIt) );
+      const VCardLine::List lines = ( *cardIt ).lines( ( *identIt ) );
       VCardLine::List::ConstIterator lineIt;
 
       // iterate over the lines
       for ( lineIt = lines.begin(); lineIt != lines.end(); ++lineIt ) {
-        identifier = (*lineIt).identifier().toLower();
+        identifier = ( *lineIt ).identifier().toLower();
         // ADR
         if ( identifier == QLatin1String( "adr" ) ) {
           Address address;
-          const QStringList addrParts = splitString( semicolonSep, (*lineIt).value().toString() );
+          const QStringList addrParts = splitString( semicolonSep, ( *lineIt ).value().toString() );
           if ( addrParts.count() > 0 ) {
             address.setPostOfficeBox( addrParts[ 0 ] );
           }
@@ -446,9 +475,9 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
           Address::Type type;
 
-          const QStringList types = (*lineIt).parameters( QLatin1String( "type" ) );
+          const QStringList types = ( *lineIt ).parameters( QLatin1String( "type" ) );
           for ( QStringList::ConstIterator it = types.begin(); it != types.end(); ++it ) {
-            type |= mAddressTypeMap[ (*it).toLower() ];
+            type |= mAddressTypeMap[ ( *it ).toLower() ];
           }
 
           address.setType( type );
@@ -457,12 +486,12 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // BDAY
         else if ( identifier == QLatin1String( "bday" ) ) {
-          addr.setBirthday( parseDateTime( (*lineIt).value().toString() ) );
+          addr.setBirthday( parseDateTime( ( *lineIt ).value().toString() ) );
         }
 
         // CATEGORIES
         else if ( identifier == QLatin1String( "categories" ) ) {
-          const QStringList categories = splitString( commaSep, (*lineIt).value().toString() );
+          const QStringList categories = splitString( commaSep, ( *lineIt ).value().toString() );
           addr.setCategories( categories );
         }
 
@@ -473,14 +502,14 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // EMAIL
         else if ( identifier == QLatin1String( "email" ) ) {
-          const QStringList types = (*lineIt).parameters( QLatin1String( "type" ) );
-          addr.insertEmail( (*lineIt).value().toString(),
+          const QStringList types = ( *lineIt ).parameters( QLatin1String( "type" ) );
+          addr.insertEmail( ( *lineIt ).value().toString().toLower(),
                             types.contains( QLatin1String( "PREF" ) ) );
         }
 
         // FN
         else if ( identifier == QLatin1String( "fn" ) ) {
-          addr.setFormattedName( (*lineIt).value().toString() );
+          addr.setFormattedName( ( *lineIt ).value().toString() );
         }
 
         // GEO
@@ -488,7 +517,7 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
           Geo geo;
 
           const QStringList geoParts =
-            (*lineIt).value().toString().split( QLatin1Char( ';' ), QString::KeepEmptyParts );
+            ( *lineIt ).value().toString().split( QLatin1Char( ';' ), QString::KeepEmptyParts );
           if ( geoParts.size() >= 2 ) {
             geo.setLatitude( geoParts[ 0 ].toFloat() );
             geo.setLongitude( geoParts[ 1 ].toFloat() );
@@ -505,17 +534,17 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
         else if ( identifier == QLatin1String( "label" ) ) {
           Address::Type type;
 
-          const QStringList types = (*lineIt).parameters( QLatin1String( "type" ) );
+          const QStringList types = ( *lineIt ).parameters( QLatin1String( "type" ) );
           for ( QStringList::ConstIterator it = types.begin(); it != types.end(); ++it ) {
-            type |= mAddressTypeMap[ (*it).toLower() ];
+            type |= mAddressTypeMap[ ( *it ).toLower() ];
           }
 
           bool available = false;
           KABC::Address::List addressList = addr.addresses();
           for ( KABC::Address::List::Iterator it = addressList.begin();
                 it != addressList.end(); ++it ) {
-            if ( (*it).type() == type ) {
-              (*it).setLabel( (*lineIt).value().toString() );
+            if ( ( *it ).type() == type ) {
+              ( *it ).setLabel( ( *lineIt ).value().toString() );
               addr.insertAddress( *it );
               available = true;
               break;
@@ -524,7 +553,7 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
           if ( !available ) { // a standalone LABEL tag
             KABC::Address address( type );
-            address.setLabel( (*lineIt).value().toString() );
+            address.setLabel( ( *lineIt ).value().toString() );
             addr.insertAddress( address );
           }
         }
@@ -536,13 +565,13 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // MAILER
         else if ( identifier == QLatin1String( "mailer" ) ) {
-          addr.setMailer( (*lineIt).value().toString() );
+          addr.setMailer( ( *lineIt ).value().toString() );
         }
 
         // N
         else if ( identifier == QLatin1String( "n" ) ) {
-          const QStringList nameParts = splitString( semicolonSep, (*lineIt).value().toString() );
-          const int numberOfParts(nameParts.count());
+          const QStringList nameParts = splitString( semicolonSep, ( *lineIt ).value().toString() );
+          const int numberOfParts( nameParts.count() );
           if ( numberOfParts > 0 ) {
             addr.setFamilyName( nameParts[ 0 ] );
           }
@@ -562,22 +591,22 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // NAME
         else if ( identifier == QLatin1String( "name" ) ) {
-          addr.setName( (*lineIt).value().toString() );
+          addr.setName( ( *lineIt ).value().toString() );
         }
 
         // NICKNAME
         else if ( identifier == QLatin1String( "nickname" ) ) {
-          addr.setNickName( (*lineIt).value().toString() );
+          addr.setNickName( ( *lineIt ).value().toString() );
         }
 
         // NOTE
         else if ( identifier == QLatin1String( "note" ) ) {
-          addr.setNote( (*lineIt).value().toString() );
+          addr.setNote( ( *lineIt ).value().toString() );
         }
 
         // ORGANIZATION
         else if ( identifier == QLatin1String( "org" ) ) {
-          const QStringList orgParts = splitString( semicolonSep, (*lineIt).value().toString() );
+          const QStringList orgParts = splitString( semicolonSep, ( *lineIt ).value().toString() );
           if ( orgParts.count() > 0 ) {
             addr.setOrganization( orgParts[ 0 ] );
           }
@@ -593,22 +622,22 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // PROID
         else if ( identifier == QLatin1String( "prodid" ) ) {
-          addr.setProductId( (*lineIt).value().toString() );
+          addr.setProductId( ( *lineIt ).value().toString() );
         }
 
         // REV
         else if ( identifier == QLatin1String( "rev" ) ) {
-          addr.setRevision( parseDateTime( (*lineIt).value().toString() ) );
+          addr.setRevision( parseDateTime( ( *lineIt ).value().toString() ) );
         }
 
         // ROLE
         else if ( identifier == QLatin1String( "role" ) ) {
-          addr.setRole( (*lineIt).value().toString() );
+          addr.setRole( ( *lineIt ).value().toString() );
         }
 
         // SORT-STRING
         else if ( identifier == QLatin1String( "sort-string" ) ) {
-          addr.setSortString( (*lineIt).value().toString() );
+          addr.setSortString( ( *lineIt ).value().toString() );
         }
 
         // SOUND
@@ -619,14 +648,14 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
         // TEL
         else if ( identifier == QLatin1String( "tel" ) ) {
           PhoneNumber phone;
-          phone.setNumber( (*lineIt).value().toString() );
+          phone.setNumber( ( *lineIt ).value().toString() );
 
           PhoneNumber::Type type;
 
-          const QStringList types = (*lineIt).parameters( QLatin1String( "type" ) );
-          QStringList::ConstIterator typeEnd(types.end());
+          const QStringList types = ( *lineIt ).parameters( QLatin1String( "type" ) );
+          QStringList::ConstIterator typeEnd( types.end() );
           for ( QStringList::ConstIterator it = types.begin(); it != typeEnd; ++it ) {
-            type |= mPhoneTypeMap[(*it).toUpper()];
+            type |= mPhoneTypeMap[( *it ).toUpper()];
           }
 
           phone.setType( type );
@@ -636,13 +665,13 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // TITLE
         else if ( identifier == QLatin1String( "title" ) ) {
-          addr.setTitle( (*lineIt).value().toString() );
+          addr.setTitle( ( *lineIt ).value().toString() );
         }
 
         // TZ
         else if ( identifier == QLatin1String( "tz" ) ) {
           TimeZone tz;
-          const QString date = (*lineIt).value().toString();
+          const QString date = ( *lineIt ).value().toString();
 
           if ( !date.isEmpty() ) {
             int hours = date.mid( 1, 2 ).toInt();
@@ -657,57 +686,64 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // UID
         else if ( identifier == QLatin1String( "uid" ) ) {
-          addr.setUid( (*lineIt).value().toString() );
+          addr.setUid( ( *lineIt ).value().toString() );
         }
 
         // URL
         else if ( identifier == QLatin1String( "url" ) ) {
-          addr.setUrl( KUrl( (*lineIt).value().toString() ) );
+          addr.setUrl( KUrl( ( *lineIt ).value().toString() ) );
         }
 
         // X-
         else if ( identifier.startsWith( QLatin1String( "x-" ) ) ) {
           QString ident = ( *lineIt ).identifier();
           //X-Evolution
-          if(identifier==QLatin1String("x-evolution-spouse") || identifier == QLatin1String("x-spouse")) {
-            ident = QLatin1String("X-KADDRESSBOOK-X-SpousesName");
-          } else if(identifier == QLatin1String("x-evolution-blog-url")) {
-            ident = QLatin1String("X-KADDRESSBOOK-BlogFeed");
-          } else if(identifier == QLatin1String("x-evolution-assistant") || identifier == QLatin1String("x-assistant")) {
-            ident = QLatin1String("X-KADDRESSBOOK-X-AssistantsName");
-          } else if(identifier == QLatin1String("x-evolution-anniversary") || identifier == QLatin1String("x-anniversary")) {
-            ident = QLatin1String("X-KADDRESSBOOK-X-Anniversary");
-          } else if(identifier == QLatin1String("x-evolution-manager") || identifier == QLatin1String("x-manager")) {
-            ident = QLatin1String("X-KADDRESSBOOK-X-ManagersName");
-          } else if(identifier == QLatin1String("x-aim")) {
-            ident = QLatin1String("X-messaging/aim-All");
-          } else if(identifier == QLatin1String("x-icq")) {
-            ident = QLatin1String("X-messaging/icq-All");
-          } else if(identifier == QLatin1String("x-jabber")) {
-            ident = QLatin1String("X-messaging/xmpp-All");
-          } else if(identifier == QLatin1String("x-jabber")) {
-            ident = QLatin1String("X-messaging/xmpp-All");
-          } else if(identifier == QLatin1String("x-msn")) {
-            ident = QLatin1String("X-messaging/msn-All");
-          } else if(identifier == QLatin1String("x-yahoo")) {
-            ident = QLatin1String("X-messaging/yahoo-All");
-          } else if(identifier == QLatin1String("x-gadugadu")) {
-            ident = QLatin1String("X-messaging/gadu-All");
-          } else if(identifier == QLatin1String("x-skype")) {
-            ident = QLatin1String("X-messaging/skype-All");
-          } else if(identifier == QLatin1String("x-groupwise")) {
-            ident = QLatin1String("X-messaging/groupwise-All");
-          } else if(identifier == QLatin1String("x-sms")) {
-            ident = QLatin1String("X-messaging/sms-All");
-          } else if(identifier == QLatin1String("x-meanwhile")) {
-            ident = QLatin1String("X-messaging/meanwhile-All");
+          if ( identifier == QLatin1String( "x-evolution-spouse" ) ||
+               identifier == QLatin1String( "x-spouse" ) ) {
+            ident = QLatin1String( "X-KADDRESSBOOK-X-SpousesName" );
+          } else if ( identifier == QLatin1String( "x-evolution-blog-url" ) ) {
+            ident = QLatin1String( "X-KADDRESSBOOK-BlogFeed" );
+          } else if ( identifier == QLatin1String( "x-evolution-assistant" ) ||
+                     identifier == QLatin1String( "x-assistant" ) ) {
+            ident = QLatin1String( "X-KADDRESSBOOK-X-AssistantsName" );
+          } else if ( identifier == QLatin1String( "x-evolution-anniversary" ) ||
+                      identifier == QLatin1String( "x-anniversary" ) ) {
+            ident = QLatin1String( "X-KADDRESSBOOK-X-Anniversary" );
+          } else if ( identifier == QLatin1String( "x-evolution-manager" ) ||
+                      identifier == QLatin1String( "x-manager" ) ) {
+            ident = QLatin1String( "X-KADDRESSBOOK-X-ManagersName" );
+          } else if ( identifier == QLatin1String( "x-aim" ) ) {
+            ident = QLatin1String( "X-messaging/aim-All" );
+          } else if ( identifier == QLatin1String( "x-icq" ) ) {
+            ident = QLatin1String( "X-messaging/icq-All" );
+          } else if ( identifier == QLatin1String( "x-jabber" ) ) {
+            ident = QLatin1String( "X-messaging/xmpp-All" );
+          } else if ( identifier == QLatin1String( "x-jabber" ) ) {
+            ident = QLatin1String( "X-messaging/xmpp-All" );
+          } else if ( identifier == QLatin1String( "x-msn" ) ) {
+            ident = QLatin1String( "X-messaging/msn-All" );
+          } else if ( identifier == QLatin1String( "x-yahoo" ) ) {
+            ident = QLatin1String( "X-messaging/yahoo-All" );
+          } else if ( identifier == QLatin1String( "x-gadugadu" ) ) {
+            ident = QLatin1String( "X-messaging/gadu-All" );
+          } else if ( identifier == QLatin1String( "x-skype" ) ) {
+            ident = QLatin1String( "X-messaging/skype-All" );
+          } else if ( identifier == QLatin1String( "x-groupwise" ) ) {
+            ident = QLatin1String( "X-messaging/groupwise-All" );
+          } else if ( identifier == QLatin1String( "x-sms" ) ) {
+            ident = QLatin1String( "X-messaging/sms-All" );
+          } else if ( identifier == QLatin1String( "x-meanwhile" ) ) {
+            ident = QLatin1String( "X-messaging/meanwhile-All" );
           } else if ( identifier == QLatin1String( "x-irc" ) ) {
             ident = QLatin1String( "X-messaging/irc-All" );
+          } else if ( identifier == QLatin1String( "x-googletalk" ) ) {
+            ident = QLatin1String( "X-messaging/googletalk-All" );
           }
 
           const QString key = ident.mid( 2 );
           const int dash = key.indexOf( QLatin1Char( '-' ) );
-          addr.insertCustom( key.left( dash ), key.mid( dash + 1 ), ( *lineIt ).value().toString() );
+          addr.insertCustom( key.left( dash ), key.mid( dash + 1 ),
+                             ( *lineIt ).value().toString() );
         }
       }
     }
@@ -759,7 +795,7 @@ QDateTime VCardTool::parseDateTime( const QString &str ) const
 
   Qt::TimeSpec spec = ( str.right( 1 ) == QLatin1String( "Z" ) ) ? Qt::UTC : Qt::LocalTime;
 
-  QDateTime dateTime(date);
+  QDateTime dateTime( date );
 
   // explicitly set the time, which might be invalid, to keep the information
   // that the time is invalid. In createDateTime() the time/invalid flag is
@@ -767,9 +803,9 @@ QDateTime VCardTool::parseDateTime( const QString &str ) const
   // This is needed to reproduce the given string in input
   // e.g. BDAY:2008-12-30
   // without time shall also result in a string without a time
-  dateTime.setTime(time);
+  dateTime.setTime( time );
 
-  dateTime.setTimeSpec(spec);
+  dateTime.setTimeSpec( spec );
   return dateTime;
 }
 
@@ -800,20 +836,18 @@ Picture VCardTool::parsePicture( const VCardLine &line ) const
   Picture pic;
 
   const QStringList params = line.parameterList();
+  QString type;
+  if ( params.contains( QLatin1String( "type" ) ) ) {
+    type = line.parameter( QLatin1String( "type" ) );
+  }
   if ( params.contains( QLatin1String( "encoding" ) ) ) {
-    QImage img;
-    img.loadFromData( line.value().toByteArray() );
-    pic.setData( img );
+    pic.setRawData( line.value().toByteArray(), type );
   } else if ( params.contains( QLatin1String( "value" ) ) ) {
     if ( line.parameter( QLatin1String( "value" ) ).toLower() == QLatin1String( "uri" ) ) {
       pic.setUrl( line.value().toString() );
     }
   }
 
-  if ( params.contains( QLatin1String( "type" ) ) ) {
-    pic.setType( line.parameter( QLatin1String( "type" ) ) );
-  }
-
   return pic;
 }
 
@@ -821,27 +855,15 @@ VCardLine VCardTool::createPicture( const QString &identifier, const Picture &pi
 {
   VCardLine line( identifier );
 
+  if ( pic.isEmpty() ) {
+    return line;
+  }
+
   if ( pic.isIntern() ) {
-    if ( !pic.data().isNull() ) {
-      QByteArray input;
-      QBuffer buffer( &input );
-      buffer.open( QIODevice::WriteOnly );
-
-      if ( !pic.data().hasAlphaChannel() ) {
-        pic.data().save( &buffer, "JPEG" );
-
-        line.setValue( input );
-        line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
-        line.addParameter( QLatin1String( "type" ), QLatin1String( "jpeg" ) );
-      } else {
-        pic.data().save( &buffer, "PNG" );
-
-        line.setValue( input );
-        line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
-        line.addParameter( QLatin1String( "type" ), QLatin1String( "png" ) );
-      }
-    }
-  } else if ( !pic.url().isEmpty() ) {
+    line.setValue( pic.rawData() );
+    line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
+    line.addParameter( QLatin1String( "type" ), pic.type() );
+  } else {
     line.setValue( pic.url() );
     line.addParameter( QLatin1String( "value" ), QLatin1String( "URI" ) );
   }
