@@ -35,12 +35,17 @@
 #include "incidence.h"
 #include "calformat.h"
 
+#include "kpimutils/kfileio.h"
+
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <ktemporaryfile.h>
+#include <kde_file.h>
 
 #include <QtCore/QList>
 #include <QTextDocument> // for Qt::escape() and Qt::mightBeRichText()
+#include <KMimeType>
 
 using namespace KCal;
 
@@ -60,7 +65,10 @@ class KCal::Incidence::Private
         mStatus( StatusNone ),
         mSecrecy( SecrecyPublic ),
         mPriority( 0 ),
-        mRelatedTo( 0 )
+        mRelatedTo( 0 ),
+        mGeoLatitude( 0 ),
+        mGeoLongitude( 0 ),
+        mHasGeo( false )
     {
       mAlarms.setAutoDelete( true );
       mAttachments.setAutoDelete( true );
@@ -76,17 +84,18 @@ class KCal::Incidence::Private
         mLocation( p.mLocation ),
         mLocationIsRich( p.mLocationIsRich ),
         mCategories( p.mCategories ),
+        mRecurrence( p.mRecurrence ),
         mResources( p.mResources ),
         mStatus( p.mStatus ),
         mStatusString( p.mStatusString ),
         mSecrecy( p.mSecrecy ),
         mPriority( p.mPriority ),
         mSchedulingID( p.mSchedulingID ),
-        mRelatedTo( 0 ),
-        mRelatedToUid( p.mRelatedToUid )
-// TODO: reenable attributes currently commented out.
-//  Incidence *mRelatedTo;          Incidence *mRelatedTo;
-//  Incidence::List mRelations;    Incidence::List mRelations;
+        mRelatedTo( p.mRelatedTo ),
+        mRelatedToUid( p.mRelatedToUid ),
+        mGeoLatitude( p.mGeoLatitude ),
+        mGeoLongitude( p.mGeoLongitude ),
+        mHasGeo( p.mHasGeo )
     {
       mAlarms.setAutoDelete( true );
       mAttachments.setAutoDelete( true );
@@ -121,7 +130,11 @@ class KCal::Incidence::Private
 
     Incidence *mRelatedTo;           // incidence this is related to
     QString mRelatedToUid;           // incidence (by Uid) this is related to
-    Incidence::List mRelations;      // a list of incidences this is related to
+    Incidence::List mRelations;      // a list of incidences related to this
+    float mGeoLatitude;              // Specifies latitude in decimal degrees
+    float mGeoLongitude;             // Specifies longitude in decimal degrees
+    bool mHasGeo;                    // if incidence has geo data
+    QHash<Attachment *, QString> mTempFiles;   // Temporary files for writing attachments to.
 };
 //@endcond
 
@@ -141,22 +154,23 @@ Incidence::Incidence( const Incidence &i )
 
 void Incidence::init( const Incidence &i )
 {
-// TODO: reenable attributes currently commented out.
   d->mRevision = i.d->mRevision;
   d->mCreated = i.d->mCreated;
   d->mDescription = i.d->mDescription;
   d->mSummary = i.d->mSummary;
   d->mCategories = i.d->mCategories;
-//  Incidence *mRelatedTo;          Incidence *mRelatedTo;
-  d->mRelatedTo = 0;
+  d->mRelatedTo = i.d->mRelatedTo;
   d->mRelatedToUid = i.d->mRelatedToUid;
-//  Incidence::List mRelations;    Incidence::List mRelations;
+  d->mRelations = i.d->mRelations;
   d->mResources = i.d->mResources;
   d->mStatusString = i.d->mStatusString;
   d->mStatus = i.d->mStatus;
   d->mSecrecy = i.d->mSecrecy;
   d->mPriority = i.d->mPriority;
   d->mLocation = i.d->mLocation;
+  d->mGeoLatitude = i.d->mGeoLatitude;
+  d->mGeoLongitude = i.d->mGeoLongitude;
+  d->mHasGeo = i.d->mHasGeo;
 
   // Alarms and Attachments are stored in ListBase<...>, which is a QValueList<...*>.
   // We need to really duplicate the objects stored therein, otherwise deleting
@@ -719,6 +733,39 @@ void Incidence::clearAttachments()
   d->mAttachments.clearAll();
 }
 
+QString Incidence::writeAttachmentToTempFile( Attachment* attachment ) const
+{
+  if ( d->mTempFiles.contains( attachment ) ) {
+    return d->mTempFiles.value( attachment );
+  }
+  KTemporaryFile *file = new KTemporaryFile();
+
+  QStringList patterns = KMimeType::mimeType( attachment->mimeType() )->patterns();
+
+  if ( !patterns.empty() ) {
+    file->setSuffix( QString( patterns.first() ).remove( '*' ) );
+  }
+  file->setAutoRemove( true );
+  file->open();
+  // read-only not to give the idea that it could be written to
+  file->setPermissions( QFile::ReadUser );
+  file->write( QByteArray::fromBase64( attachment->data() ) );
+  d->mTempFiles.insert( attachment, file->fileName() );
+  file->close();
+  return d->mTempFiles.value( attachment );
+}
+
+void Incidence::clearTempFiles()
+{
+  QHash<Attachment*, QString>::const_iterator it = d->mTempFiles.constBegin();
+  const QHash<Attachment*, QString>::const_iterator end = d->mTempFiles.constEnd();
+  for ( ; it != end; ++it )
+  {
+    QFile::remove( it.value() );
+  }
+  d->mTempFiles.clear();
+}
+
 void Incidence::setResources( const QStringList &resources )
 {
   if ( mReadOnly ) {
@@ -944,6 +991,51 @@ QString Incidence::schedulingID() const
   return d->mSchedulingID;
 }
 
+bool Incidence::hasGeo() const
+{
+  return d->mHasGeo;
+}
+
+void Incidence::setHasGeo( bool hasGeo )
+{
+  if ( mReadOnly ) {
+    return;
+  }
+
+  d->mHasGeo = hasGeo;
+  updated();
+}
+
+float &Incidence::geoLatitude() const
+{
+  return d->mGeoLatitude;
+}
+
+void Incidence::setGeoLatitude( float geolatitude )
+{
+  if ( mReadOnly ) {
+    return;
+  }
+
+  d->mGeoLatitude = geolatitude;
+  updated();
+}
+
+float &Incidence::geoLongitude() const
+{
+  return d->mGeoLongitude;
+}
+
+void Incidence::setGeoLongitude( float geolongitude )
+{
+  if ( mReadOnly ) {
+    return;
+  }
+
+  d->mGeoLongitude = geolongitude;
+  updated();
+}
+
 /** Observer interface for the recurrence class. If the recurrence is changed,
     this method will be called for the incidence the recurrence object
     belongs to. */
