@@ -82,7 +82,7 @@ bool ICalFormat::load( const Calendar::Ptr &calendar, const QString &fileName )
 
   QFile file( fileName );
   if ( !file.open( QIODevice::ReadOnly ) ) {
-    kDebug() << "load error";
+    kError() << "load error";
     setException( new Exception( Exception::LoadError ) );
     return false;
   }
@@ -154,7 +154,7 @@ bool ICalFormat::fromRawString( const Calendar::Ptr &cal, const QByteArray &stri
   // Let's defend const correctness until the very gates of hell^Wlibical
   calendar = icalcomponent_new_from_string( const_cast<char*>( ( const char * )string ) );
   if ( !calendar ) {
-    kDebug() << "parse error";
+    kError() << "parse error ; string is empty?" << string.isEmpty();
     setException( new Exception( Exception::ParseErrorIcal ) );
     return false;
   }
@@ -167,7 +167,7 @@ bool ICalFormat::fromRawString( const Calendar::Ptr &cal, const QByteArray &stri
           comp; comp = icalcomponent_get_next_component( calendar, ICAL_VCALENDAR_COMPONENT ) ) {
       // put all objects into their proper places
       if ( !d->mImpl->populate( cal, comp, deleted ) ) {
-        kDebug() << "Could not populate calendar";
+        kError() << "Could not populate calendar";
         if ( !exception() ) {
           setException( new Exception( Exception::ParseErrorKcal ) );
         }
@@ -236,7 +236,7 @@ QString ICalFormat::toString( const Calendar::Ptr &cal,
   Todo::List todoList = deleted ? cal->deletedTodos() : cal->rawTodos();
   Todo::List::ConstIterator it;
   for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
-    if ( !deleted || !cal->todo( (*it)->uid(), (*it)->recurrenceId() ) ) {
+    if ( !deleted || !cal->todo( ( *it )->uid(), ( *it )->recurrenceId() ) ) {
       // use existing ones, or really deleted ones
       if ( notebook.isEmpty() ||
            ( !cal->notebook( *it ).isEmpty() && notebook.endsWith( cal->notebook( *it ) ) ) ) {
@@ -249,7 +249,7 @@ QString ICalFormat::toString( const Calendar::Ptr &cal,
   Event::List events = deleted ? cal->deletedEvents() : cal->rawEvents();
   Event::List::ConstIterator it2;
   for ( it2 = events.constBegin(); it2 != events.constEnd(); ++it2 ) {
-    if ( !deleted || !cal->event( (*it2)->uid(), (*it2)->recurrenceId() ) ) {
+    if ( !deleted || !cal->event( ( *it2 )->uid(), ( *it2 )->recurrenceId() ) ) {
       // use existing ones, or really deleted ones
       if ( notebook.isEmpty() ||
            ( !cal->notebook( *it2 ).isEmpty() && notebook.endsWith( cal->notebook( *it2 ) ) ) ) {
@@ -263,7 +263,7 @@ QString ICalFormat::toString( const Calendar::Ptr &cal,
   Journal::List journals = deleted ? cal->deletedJournals() : cal->rawJournals();
   Journal::List::ConstIterator it3;
   for ( it3 = journals.constBegin(); it3 != journals.constEnd(); ++it3 ) {
-    if ( !deleted || !cal->journal( (*it3)->uid(), (*it3)->recurrenceId() ) ) {
+    if ( !deleted || !cal->journal( ( *it3 )->uid(), ( *it3 )->recurrenceId() ) ) {
       // use existing ones, or really deleted ones
       if ( notebook.isEmpty() ||
            ( !cal->notebook( *it3 ).isEmpty() && notebook.endsWith( cal->notebook( *it3 ) ) ) ) {
@@ -280,9 +280,9 @@ QString ICalFormat::toString( const Calendar::Ptr &cal,
     // this will export a calendar having only timezone definitions
     zones = tzlist->zones();
   }
-  for ( ICalTimeZones::ZoneMap::ConstIterator it=zones.constBegin();
+  for ( ICalTimeZones::ZoneMap::ConstIterator it = zones.constBegin();
         it != zones.constEnd(); ++it ) {
-    icaltimezone *tz = (*it).icalTimezone();
+    icaltimezone *tz = ( *it ).icalTimezone();
     if ( !tz ) {
       kError() << "bad time zone";
     } else {
@@ -294,7 +294,7 @@ QString ICalFormat::toString( const Calendar::Ptr &cal,
 
   char *const componentString = icalcomponent_as_ical_string_r( calendar );
   const QString &text = QString::fromUtf8( componentString );
-  free(componentString);
+  free( componentString );
 
   icalcomponent_free( calendar );
   icalmemory_free_ring();
@@ -330,9 +330,9 @@ QByteArray ICalFormat::toRawString( const Incidence::Ptr &incidence )
 
   // time zones
   ICalTimeZones::ZoneMap zones = tzUsedList.zones();
-  for ( ICalTimeZones::ZoneMap::ConstIterator it=zones.constBegin();
+  for ( ICalTimeZones::ZoneMap::ConstIterator it = zones.constBegin();
         it != zones.constEnd(); ++it ) {
-    icaltimezone *tz = (*it).icalTimezone();
+    icaltimezone *tz = ( *it ).icalTimezone();
     if ( !tz ) {
       kError() << "bad time zone";
     } else {
