@@ -177,10 +177,11 @@ void kio_sieveResponse::clear()
 /* ---------------------------------------------------------------------------------- */
 kio_sieveProtocol::kio_sieveProtocol(const QByteArray &pool_socket, const QByteArray &app_socket)
 	: TCPSlaveBase("sieve", pool_socket, app_socket, false)
-	, m_connMode(NORMAL)
-	, m_supportsTLS(false)
-	, m_shouldBeConnected(false)
+        , m_connMode(NORMAL)
+        , m_supportsTLS(false)
+        , m_shouldBeConnected(false)
         , m_allowUnencrypted(false)
+        , m_port(SIEVE_DEFAULT_PORT)
 {
 }
 
@@ -345,23 +346,23 @@ bool kio_sieveProtocol::connect(bool useTLSIfAvailable)
 	}
 
 
-        // Attempt to start TLS
-        if ( !m_allowUnencrypted && !QSslSocket::supportsSsl() ) {
-            error( ERR_SLAVE_DEFINED, i18n("Can not use TLS since the underlying Qt library does not support it.") );
-            disconnect();
-            return false;
-        }
+  // Attempt to start TLS
+  if ( !m_allowUnencrypted && !QSslSocket::supportsSsl() ) {
+    error( ERR_SLAVE_DEFINED, i18n("Can not use TLS since the underlying Qt library does not support it.") );
+    disconnect();
+    return false;
+  }
 
-        if ( !m_allowUnencrypted && useTLSIfAvailable && QSslSocket::supportsSsl() && !m_supportsTLS &&
-             messageBox( WarningContinueCancel,
-                         i18n("TLS encryption was requested, but your Sieve server does not advertise TLS in its capabilities.\n"
-                              "You can choose to try to initiate TLS negotiations nonetheless, or cancel the operation."),
-                         i18n("Server Does Not Advertise TLS"), i18n("&Start TLS nonetheless"), i18n("&Cancel") ) != KMessageBox::Continue )
-        {
-            error( ERR_USER_CANCELED, i18n("TLS encryption requested, but not supported by server.") );
-            disconnect();
-            return false;
-        }
+  if ( !m_allowUnencrypted && useTLSIfAvailable && QSslSocket::supportsSsl() && !m_supportsTLS &&
+       messageBox( WarningContinueCancel,
+                   i18n("TLS encryption was requested, but your Sieve server does not advertise TLS in its capabilities.\n"
+                        "You can choose to try to initiate TLS negotiations nonetheless, or cancel the operation."),
+                   i18n("Server Does Not Advertise TLS"), i18n("&Start TLS nonetheless"), i18n("&Cancel") ) != KMessageBox::Continue )
+  {
+    error( ERR_USER_CANCELED, i18n("TLS encryption requested, but not supported by server.") );
+    disconnect();
+    return false;
+  }
 
 	// FIXME find a test server and test that this works
   if (useTLSIfAvailable && m_supportsTLS && QSslSocket::supportsSsl()) {
