@@ -59,13 +59,16 @@ class TextEditPrivate
     TextEditPrivate( TextEdit *parent )
       : actionAddImage( 0 ),
         actionDeleteLine( 0 ),
+        actionAddEmoticon( 0 ),
         actionInsertHtml( 0 ),
         actionTable( 0 ),
+        actionFormatReset( 0 ),
         q( parent ),
         imageSupportEnabled( false ),
         emoticonSupportEnabled( false ),
         insertHtmlSupportEnabled( false ),
-        insertTableSupportEnabled( false )
+        insertTableSupportEnabled( false ),
+        spellCheckingEnabled( false )
     {
     }
 
@@ -382,13 +385,23 @@ QString TextEdit::toWrappedPlainText() const
 QString TextEdit::toWrappedPlainText(QTextDocument* doc) const
 {
   QString temp;
+  QRegExp rx( QLatin1String( "(http|ftp|ldap)s?\\S+-$" ) );
   QTextBlock block = doc->begin();
   while ( block.isValid() ) {
     QTextLayout *layout = block.layout();
     const int numberOfLine( layout->lineCount() );
+    bool urlStart = false;
     for ( int i = 0; i < numberOfLine; ++i ) {
       QTextLine line = layout->lineAt( i );
-      temp += block.text().mid( line.textStart(), line.textLength() ) + QLatin1Char( '\n' );
+      QString lineText = block.text().mid( line.textStart(), line.textLength() );
+
+      if ( lineText.contains(rx) || ( urlStart && !lineText.contains( QLatin1Char(' ') ) && lineText.endsWith( QLatin1Char('-') ) ) ) {
+        // don't insert line break in URL
+        temp += lineText;
+        urlStart = true;
+      } else {
+        temp += lineText + QLatin1Char( '\n' );
+      }
     }
     block = block.next();
   }
